@@ -1,4 +1,4 @@
-context("Test list indices")
+message("\n---- Test list indices ----")
 # testthat::skip_on_cran()
 # testthat::skip_on_travis()
 
